@@ -1,5 +1,3 @@
-#
-
 package Mail::Mailer;
 
 use POSIX qw/_exit/;
@@ -45,7 +43,7 @@ The smtp mailer does not handle C<Cc> and C<Bcc> lines, neither their
 C<Resent-*> fellows. The C<Debug> options enables debugging output
 from C<Net::SMTP>.
 
-You may also use the C< Auth => [ $user, $password ] > option for SASL
+You may also use the C<< Auth => [ $user, $password ] >> option for SASL
 authentication (requires L<Authen::SASL> and L<MIME::Base64>).
 
 =item C<qmail>
@@ -129,7 +127,7 @@ use vars qw(@ISA $VERSION $MailerBinary $MailerType %Mailers @Mailers);
 use Config;
 use strict;
 
-$VERSION = "1.73";
+$VERSION = "1.76";
 
 sub Version { $VERSION }
 
@@ -263,22 +261,29 @@ sub open {
 # removed MO 20050331: destroyed the folding
 #   _cleanup_hdrs($hdrs);
 
-    my @to = $self->who_to($hdrs);
+    my @to     = $self->who_to($hdrs);
+    my $sender = $self->who_sender($hdrs);
     
     $self->close;	# just in case;
 
-    # Fork and start a mailer
-    my $child = open $self, '|-';
-    defined $child or die "Failed to send: $!";
+    if(defined $exe)
+    {   # Fork and start a mailer
+        my $child = open $self, '|-';
+        defined $child or die "Failed to send: $!";
 
-    if($child==0)
-    {   # Child process will handle sending, but this is not real exec()
-        # this is a setup!!!
-        unless($self->exec($exe, $args, \@to))
-        {   warn $!;     # setup failed
-            _exit(1);    # no DESTROY(), keep it for parent
+        if($child==0)
+        {   # Child process will handle sending, but this is not real exec()
+            # this is a setup!!!
+            unless($self->exec($exe, $args, \@to, $sender))
+            {   warn $!;     # setup failed
+                _exit(1);    # no DESTROY(), keep it for parent
+            }
         }
     }
+    else
+    {   $self->exec($exe, $args, \@to, $sender)
+            or die $!;
+    }
 
     # Set the headers
     $self->set_headers($hdrs);
@@ -320,6 +325,11 @@ sub who_to {
     @to;
 }
 
+sub who_sender {
+    my($self, $hdrs) = @_;
+    ($self->to_array($hdrs->{Sender} || $hdrs->{From}))[0];
+}
+
 sub epilogue {
     # This could send a .signature, also see ::smtp subclass
 }
